==> ui-18.0.5.tgz: package/components/auto-complete/AutoComplete.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { createElement as _createElement } from "react";
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useState, useCallback, useRef, useImperativeHandle, useMemo } from 'react';
import ReactDOM from 'react-dom';
import { useEvent, useEventCallback, useId, useRefExtra, useResize } from '@react-devui/hooks';
import { LoadingOutlined } from '@react-devui/icons';
import { findNested, getClassName, getVerticalSidePosition } from '@react-devui/utils';
import { useMaxIndex, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate, TTANSITION_DURING_POPUP, WINDOW_SPACE } from '../../utils';
import { DFocusVisible } from '../_focus-visible';
import { DComboboxKeyboard } from '../_keyboard';
import { DTransition } from '../_transition';
import { DInput } from '../input';
import { useComponentConfig, useGlobalScroll, useLayout, usePrefixConfig, useTranslation } from '../root';
import { DVirtualScroll } from '../virtual-scroll';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DAutoComplete' });
function AutoComplete(props, ref) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dList, dVisible, dLoading = false, dCustomItem, onVisibleChange, onItemClick, onScrollBottom, afterVisibleChange } = _a, restProps = __rest(_a, ["children", "dList", "dVisible", "dLoading", "dCustomItem", "onVisibleChange", "onItemClick", "onScrollBottom", "afterVisibleChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { dPageScrollRef, dContentResizeRef } = useLayout();
    //#endregion
    //#region Ref
    const boxRef = useRefExtra(() => document.querySelector(`[data-auto-complete-box="${uniqueId}"]`));
    const popupRef = useRef(null);
    const vsRef = useRef(null);
    const containerRef = useRefExtra(() => {
        let el = document.getElementById(`${dPrefix}auto-complete-root`);
        if (!el) {
            el = document.createElement('div');
            el.id = `${dPrefix}auto-complete-root`;
            document.body.appendChild(el);
        }
        return el;
    }, true);
    //#endregion
    const [t] = useTranslation();
    const uniqueId = useId();
    const listId = `${dPrefix}auto-complete-list-${uniqueId}`;
    const getGroupId = (val) => `${dPrefix}auto-complete-group-${val}-${uniqueId}`;
    const getItemId = (val) => `${dPrefix}auto-complete-item-${val}-${uniqueId}`;
    const canSelectItem = useCallback((item) => !item.disabled && !item.children, []);
    const [visible, changeVisible] = useDValue(false, dVisible, onVisibleChange);
    const [focusVisible, setFocusVisible] = useState(false);
    const maxZIndex = useMaxIndex(visible);
    const [popupPositionStyle, setPopupPositionStyle] = useState({
        top: '-200vh',
        left: '-200vw',
    });
    const [transformOrigin, setTransformOrigin] = useState();
    const updatePosition = useEventCallback(() => {
        if (visible && boxRef.current && popupRef.current) {
            const boxWidth = boxRef.current.offsetWidth;
            const height = popupRef.current.offsetHeight;
            const maxWidth = window.innerWidth - WINDOW_SPACE * 2;
            const width = Math.min(Math.max(popupRef.current.scrollWidth, boxWidth), maxWidth);
            const { top, left, transformOrigin } = getVerticalSidePosition(boxRef.current, { width, height }, {
                placement: 'bottom-left',
                inWindow: WINDOW_SPACE,
            });
            setPopupPositionStyle({
                top,
                left,
                minWidth: Math.min(boxWidth, maxWidth),
                maxWidth,
            });
            setTransformOrigin(transformOrigin);
        }
    });
    const [_focusItem, setFocusItem] = useState();
    const focusItem = (() => {
        if (_focusItem && findNested(dList, (item) => canSelectItem(item) && item.value === _focusItem.value)) {
            return _focusItem;
        }
        return findNested(dList, (item) => canSelectItem(item));
    })();
    const changeFocusItem = (item) => {
        if (!isUndefined(item)) {
            setFocusItem(item);
        }
    };
    const globalScroll = useGlobalScroll(updatePosition, !visible);
    useEvent(dPageScrollRef, 'scroll', updatePosition, { passive: true }, !visible || globalScroll);
    useResize(boxRef, updatePosition, !visible);
    useResize(popupRef, updatePosition, !visible);
    useResize(dContentResizeRef, updatePosition, !visible);
    const preventBlur = (e) => {
        if (e.button === 0) {
            e.preventDefault();
        }
    };
    useImperativeHandle(ref, () => ({
        updatePosition,
    }), [updatePosition]);
    const child = React.Children.only(children);
    const vsPerformance = useMemo(() => ({
        dList,
        dItemSize: 32,
        dItemNested: (item) => ({
            list: item.children,
            emptySize: 32,
            inAriaSetsize: false,
        }),
        dItemKey: (item) => item.value,
        dFocusable: canSelectItem,
    }), [canSelectItem, dList]);
    return (_jsxs(_Fragment, { children: [_jsx(DFocusVisible, Object.assign({ onFocusVisibleChange: setFocusVisible }, { children: ({ render: renderFocusVisible }) => (_jsx(DComboboxKeyboard, Object.assign({ dVisible: visible, dEditable: true, dHasSub: false, onVisibleChange: changeVisible, onFocusChange: (key) => {
                        var _a, _b, _c, _d;
                        switch (key) {
                            case 'next':
                                changeFocusItem((_a = vsRef.current) === null || _a === void 0 ? void 0 : _a.scrollToStep(1));
                                break;
                            case 'prev':
                                changeFocusItem((_b = vsRef.current) === null || _b === void 0 ? void 0 : _b.scrollToStep(-1));
                                break;
                            case 'first':
                                changeFocusItem((_c = vsRef.current) === null || _c === void 0 ? void 0 : _c.scrollToStart());
                                break;
                            case 'last':
                                changeFocusItem((_d = vsRef.current) === null || _d === void 0 ? void 0 : _d.scrollToEnd());
                                break;
                            default:
                                break;
                        }
                    } }, { children: ({ render: renderComboboxKeyboard }) => {
                        const renderInput = (el, props) => renderFocusVisible(renderComboboxKeyboard(cloneHTMLElement(el, Object.assign(Object.assign({}, props), { role: 'combobox', 'aria-autocomplete': 'list', 'aria-expanded': visible, 'aria-controls': listId, onBlur: (e) => {
                                var _a, _b;
                                (_b = (_a = el.props).onBlur) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                                changeVisible(false);
                            }, onClick: (e) => {
                                var _a, _b;
                                (_b = (_a = el.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                                changeVisible(true);
                            }, onKeyDown: (e) => {
                                var _a, _b;
                                (_b = (_a = el.props).onKeyDown) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                                if (e.code === 'Enter' && visible && focusItem) {
                                    changeVisible(false);
                                    onItemClick === null || onItemClick === void 0 ? void 0 : onItemClick(focusItem.value, focusItem);
                                }
                            } }))));
                        const boxSelector = { ['data-auto-complete-box']: uniqueId };
                        if (child.type === DInput) {
                            return React.cloneElement(child, Object.assign(Object.assign({}, boxSelector), { dInputRender: renderInput }));
                        }
                        else {
                            return renderInput(child, boxSelector);
                        }
                    } }))) })), containerRef.current &&
                ReactDOM.createPortal(_jsx(DTransition, Object.assign({ dIn: visible, dDuring: TTANSITION_DURING_POPUP, onEnter: updatePosition, afterEnter: () => {
                        afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(true);
                    }, afterLeave: () => {
                        afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(false);
                    } }, { children: (state) => {
                        let transitionStyle = {};
                        switch (state) {
                            case 'enter':
                                transitionStyle = { transform: 'scaleY(0.7)', opacity: 0 };
                                break;
                            case 'entering':
                                transitionStyle = {
                                    transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_POPUP}ms ease-out`).join(', '),
                                    transformOrigin,
                                };
                                break;
                            case 'leaving':
                                transitionStyle = {
                                    transform: 'scaleY(0.7)',
                                    opacity: 0,
                                    transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_POPUP}ms ease-in`).join(', '),
                                    transformOrigin,
                                };
                                break;
                            case 'leaved':
                                transitionStyle = { display: 'none' };
                                break;
                            default:
                                break;
                        }
                        return (_jsxs("div", Object.assign({}, restProps, { ref: popupRef, className: getClassName(restProps.className, `${dPrefix}auto-complete`), style: Object.assign(Object.assign(Object.assign(Object.assign({}, restProps.style), popupPositionStyle), { zIndex: maxZIndex }), transitionStyle), onMouseDown: (e) => {
                                var _a;
                                (_a = restProps.onMouseDown) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                                preventBlur(e);
                            }, onMouseUp: (e) => {
                                var _a;
                                (_a = restProps.onMouseUp) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                                preventBlur(e);
                            } }, { children: [dLoading && (_jsx("div", Object.assign({ className: getClassName(`${dPrefix}auto-complete__loading`, {
                                        [`${dPrefix}auto-complete__loading--empty`]: dList.length === 0,
                                    }) }, { children: _jsx(LoadingOutlined, { dSize: dList.length === 0 ? 18 : 24, dSpin: true }) }))), _jsx(DVirtualScroll, Object.assign({}, vsPerformance, { ref: vsRef, dFillNode: _jsx("li", {}), dItemRender: (item, index, { aria, vsList }, parent) => {
                                        const { value: itemValue, disabled: itemDisabled, children } = item;
                                        const itemNode = dCustomItem ? dCustomItem(item) : itemValue;
                                        if (children) {
                                            return (_jsxs("ul", Object.assign({ className: `${dPrefix}auto-complete__option-group`, role: "group", "aria-labelledby": getGroupId(itemValue) }, { children: [_jsx("li", Object.assign({ id: getGroupId(itemValue), className: `${dPrefix}auto-complete__option-group-label`, role: "presentation" }, { children: _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: itemNode })) }), itemValue), vsList] }), itemValue));
                                        }
                                        return (_createElement("li", Object.assign({}, aria, { key: itemValue, id: getItemId(itemValue), className: getClassName(`${dPrefix}auto-complete__option`, {
                                                'is-disabled': itemDisabled,
                                            }), style: { paddingLeft: parent.length === 0 ? undefined : 12 + 8 }, title: itemValue, role: "option", "aria-selected": false, "aria-disabled": itemDisabled, onClick: () => {
                                                if (!itemDisabled) {
                                                    changeFocusItem(item);
                                                    changeVisible(false);
                                                    onItemClick === null || onItemClick === void 0 ? void 0 : onItemClick(itemValue, item);
                                                }
                                            } }),
                                            focusVisible && (focusItem === null || focusItem === void 0 ? void 0 : focusItem.value) === itemValue && _jsx("div", { className: `${dPrefix}focus-outline` }),
                                            _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: itemNode }))));
                                    }, dFocusItem: focusItem, dSize: 264, dPadding: 4, dEmptyRender: () => (_jsx("li", Object.assign({ className: `${dPrefix}auto-complete__empty`, style: { paddingLeft: 12 + 8 } }, { children: _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: t('No Data') })) }))), onScrollEnd: onScrollBottom }, { children: ({ render, vsList }) => render(_jsx("ul", Object.assign({ id: listId, className: `${dPrefix}auto-complete__list`, style: { pointerEvents: dLoading ? 'none' : undefined }, tabIndex: -1, role: "listbox", "aria-activedescendant": isUndefined(focusItem) ? undefined : getItemId(focusItem.value) }, { children: dList.length === 0 ? (_jsx("li", Object.assign({ className: `${dPrefix}auto-complete__empty` }, { children: _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: t('No Data') })) }))) : (vsList) }))) }))] })));
                    } })), containerRef.current)] }));
}
export const DAutoComplete = React.forwardRef(AutoComplete);

==> ui-18.1.1.tgz: package/components/auto-complete/AutoComplete.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { createElement as _createElement } from "react";
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useState, useCallback, useRef, useImperativeHandle, useMemo } from 'react';
import ReactDOM from 'react-dom';
import { useEvent, useEventCallback, useId, useRefExtra, useResize } from '@react-devui/hooks';
import { LoadingOutlined } from '@react-devui/icons';
import { findNested, getClassName, getVerticalSidePosition } from '@react-devui/utils';
import { useMaxIndex, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate, TTANSITION_DURING_POPUP, WINDOW_SPACE } from '../../utils';
import { DFocusVisible } from '../_focus-visible';
import { DComboboxKeyboard } from '../_keyboard';
import { DTransition } from '../_transition';
import { DInput } from '../input';
import { useComponentConfig, useGlobalScroll, useLayout, usePrefixConfig, useTranslation } from '../root';
import { DVirtualScroll } from '../virtual-scroll';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DAutoComplete' });
function AutoComplete(props, ref) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dList, dVisible, dLoading = false, dCustomItem, onVisibleChange, onItemClick, onScrollBottom, afterVisibleChange } = _a, restProps = __rest(_a, ["children", "dList", "dVisible", "dLoading", "dCustomItem", "onVisibleChange", "onItemClick", "onScrollBottom", "afterVisibleChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { dPageScrollRef, dContentResizeRef } = useLayout();
    //#endregion
    //#region Ref
    const boxRef = useRefExtra(() => document.querySelector(`[data-auto-complete-box="${uniqueId}"]`));
    const popupRef = useRef(null);
    const vsRef = useRef(null);
    const containerRef = useRefExtra(() => {
        let el = document.getElementById(`${dPrefix}auto-complete-root`);
        if (!el) {
            el = document.createElement('div');
            el.id = `${dPrefix}auto-complete-root`;
            document.body.appendChild(el);
        }
        return el;
    }, true);
    //#endregion
    const [t] = useTranslation();
    const uniqueId = useId();
    const listId = `${dPrefix}auto-complete-list-${uniqueId}`;
    const getGroupId = (val) => `${dPrefix}auto-complete-group-${val}-${uniqueId}`;
    const getItemId = (val) => `${dPrefix}auto-complete-item-${val}-${uniqueId}`;
    const canSelectItem = useCallback((item) => !item.disabled && !item.children, []);
    const [visible, changeVisible] = useDValue(false, dVisible, onVisibleChange);
    const [focusVisible, setFocusVisible] = useState(false);
    const maxZIndex = useMaxIndex(visible);
    const [popupPositionStyle, setPopupPositionStyle] = useState({
        top: '-200vh',
        left: '-200vw',
    });
    const [transformOrigin, setTransformOrigin] = useState();
    const updatePosition = useEventCallback(() => {
        if (visible && boxRef.current && popupRef.current) {
            const boxWidth = boxRef.current.offsetWidth;
            const height = popupRef.current.offsetHeight;
            const maxWidth = window.innerWidth - WINDOW_SPACE * 2;
            const width = Math.min(Math.max(popupRef.current.scrollWidth, boxWidth), maxWidth);
            const { top, left, transformOrigin } = getVerticalSidePosition(boxRef.current, { width, height }, {
                placement: 'bottom-left',
                inWindow: WINDOW_SPACE,
            });
            setPopupPositionStyle({
                top,
                left,
                minWidth: Math.min(boxWidth, maxWidth),
                maxWidth,
            });
            setTransformOrigin(transformOrigin);
        }
    });
    const [_focusItem, setFocusItem] = useState();
    const focusItem = (() => {
        if (_focusItem && findNested(dList, (item) => canSelectItem(item) && item.value === _focusItem.value)) {
            return _focusItem;
        }
        return findNested(dList, (item) => canSelectItem(item));
    })();
    const changeFocusItem = (item) => {
        if (!isUndefined(item)) {
            setFocusItem(item);
        }
    };
    const globalScroll = useGlobalScroll(updatePosition, !visible);
    useEvent(dPageScrollRef, 'scroll', updatePosition, { passive: true }, !visible || globalScroll);
    useResize(boxRef, updatePosition, !visible);
    useResize(popupRef, updatePosition, !visible);
    useResize(dContentResizeRef, updatePosition, !visible);
    const preventBlur = (e) => {
        if (e.button === 0) {
            e.preventDefault();
        }
    };
    useImperativeHandle(ref, () => ({
        updatePosition,
    }), [updatePosition]);
    const child = React.Children.only(children);
    const vsPerformance = useMemo(() => ({
        dList,
        dItemSize: 32,
        dItemNested: (item) => ({
            list: item.children,
            emptySize: 32,
            inAriaSetsize: false,
        }),
        dItemKey: (item) => item.value,
        dFocusable: canSelectItem,
    }), [canSelectItem, dList]);
    return (_jsxs(_Fragment, { children: [_jsx(DFocusVisible, Object.assign({ onFocusVisibleChange: setFocusVisible }, { children: ({ render: renderFocusVisible }) => (_jsx(DComboboxKeyboard, Object.assign({ dVisible: visible, dEditable: true, dHasSub: false, onVisibleChange: changeVisible, onFocusChange: (key) => {
                        var _a, _b, _c, _d;
                        switch (key) {
                            case 'next':
                                changeFocusItem((_a = vsRef.current) === null || _a === void 0 ? void 0 : _a.scrollToStep(1));
                                break;
                            case 'prev':
                                changeFocusItem((_b = vsRef.current) === null || _b === void 0 ? void 0 : _b.scrollToStep(-1));
                                break;
                            case 'first':
                                changeFocusItem((_c = vsRef.current) === null || _c === void 0 ? void 0 : _c.scrollToStart());
                                break;
                            case 'last':
                                changeFocusItem((_d = vsRef.current) === null || _d === void 0 ? void 0 : _d.scrollToEnd());
                                break;
                            default:
                                break;
                        }
                    } }, { children: ({ render: renderComboboxKeyboard }) => {
                        const renderInput = (el, props) => renderFocusVisible(renderComboboxKeyboard(cloneHTMLElement(el, Object.assign(Object.assign({}, props), { role: 'combobox', 'aria-autocomplete': 'list', 'aria-expanded': visible, 'aria-controls': listId, onBlur: (e) => {
                                var _a, _b;
                                (_b = (_a = el.props).onBlur) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                                changeVisible(false);
                            }, onClick: (e) => {
                                var _a, _b;
                                (_b = (_a = el.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                                changeVisible(true);
                            }, onKeyDown: (e) => {
                                var _a, _b;
                                (_b = (_a = el.props).onKeyDown) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                                if (e.code === 'Enter' && !e.shiftKey && visible && focusItem) {
                                    changeVisible(false);
                                    onItemClick === null || onItemClick === void 0 ? void 0 : onItemClick(focusItem.value, focusItem);
                                }
                            } }))));
                        const boxSelector = { ['data-auto-complete-box']: uniqueId };
                        if (child.type === DInput) {
                            return React.cloneElement(child, Object.assign(Object.assign({}, boxSelector), { dInputRender: renderInput }));
                        }
                        else {
                            return renderInput(child, boxSelector);
                        }
                    } }))) })), containerRef.current &&
                ReactDOM.createPortal(_jsx(DTransition, Object.assign({ dIn: visible, dDuring: TTANSITION_DURING_POPUP, onEnter: updatePosition, afterEnter: () => {
                        afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(true);
                    }, afterLeave: () => {
                        afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(false);
                    } }, { children: (state) => {
                        let transitionStyle = {};
                        switch (state) {
                            case 'enter':
                                transitionStyle = { transform: 'scaleY(0.7)', opacity: 0 };
                                break;
                            case 'entering':
                                transitionStyle = {
                                    transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_POPUP}ms ease-out`).join(', '),
                                    transformOrigin,
                                };
                                break;
                            case 'leaving':
                                transitionStyle = {
                                    transform: 'scaleY(0.7)',
                                    opacity: 0,
                                    transition: ['transform', 'opacity'].map((attr) => `${attr} ${TTANSITION_DURING_POPUP}ms ease-in`).join(', '),
                                    transformOrigin,
                                };
                                break;
                            case 'leaved':
                                transitionStyle = { display: 'none' };
                                break;
                            default:
                                break;
                        }
                        return (_jsxs("div", Object.assign({}, restProps, { ref: popupRef, className: getClassName(restProps.className, `${dPrefix}auto-complete`), style: Object.assign(Object.assign(Object.assign(Object.assign({}, restProps.style), popupPositionStyle), { zIndex: maxZIndex }), transitionStyle), onMouseDown: (e) => {
                                var _a;
                                (_a = restProps.onMouseDown) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                                preventBlur(e);
                            }, onMouseUp: (e) => {
                                var _a;
                                (_a = restProps.onMouseUp) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                                preventBlur(e);
                            } }, { children: [dLoading && (_jsx("div", Object.assign({ className: getClassName(`${dPrefix}auto-complete__loading`, {
                                        [`${dPrefix}auto-complete__loading--empty`]: dList.length === 0,
                                    }) }, { children: _jsx(LoadingOutlined, { dSize: dList.length === 0 ? 18 : 24, dSpin: true }) }))), _jsx(DVirtualScroll, Object.assign({}, vsPerformance, { ref: vsRef, dFillNode: _jsx("li", {}), dItemRender: (item, index, { aria, vsList }, parent) => {
                                        const { value: itemValue, disabled: itemDisabled, children } = item;
                                        const itemNode = dCustomItem ? dCustomItem(item) : itemValue;
                                        if (children) {
                                            return (_jsxs("ul", Object.assign({ className: `${dPrefix}auto-complete__option-group`, role: "group", "aria-labelledby": getGroupId(itemValue) }, { children: [_jsx("li", Object.assign({ id: getGroupId(itemValue), className: `${dPrefix}auto-complete__option-group-label`, role: "presentation" }, { children: _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: itemNode })) }), itemValue), vsList] }), itemValue));
                                        }
                                        return (_createElement("li", Object.assign({}, aria, { key: itemValue, id: getItemId(itemValue), className: getClassName(`${dPrefix}auto-complete__option`, {
                                                'is-disabled': itemDisabled,
                                            }), style: { paddingLeft: parent.length === 0 ? undefined : 12 + 8 }, title: itemValue, role: "option", "aria-selected": false, "aria-disabled": itemDisabled, onClick: () => {
                                                if (!itemDisabled) {
                                                    changeFocusItem(item);
                                                    changeVisible(false);
                                                    onItemClick === null || onItemClick === void 0 ? void 0 : onItemClick(itemValue, item);
                                                }
                                            } }),
                                            focusVisible && (focusItem === null || focusItem === void 0 ? void 0 : focusItem.value) === itemValue && _jsx("div", { className: `${dPrefix}focus-outline` }),
                                            _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: itemNode }))));
                                    }, dFocusItem: focusItem, dSize: 264, dPadding: 4, dEmptyRender: () => (_jsx("li", Object.assign({ className: `${dPrefix}auto-complete__empty`, style: { paddingLeft: 12 + 8 } }, { children: _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: t('No Data') })) }))), onScrollEnd: onScrollBottom }, { children: ({ render, vsList }) => render(_jsx("ul", Object.assign({ id: listId, className: `${dPrefix}auto-complete__list`, style: { pointerEvents: dLoading ? 'none' : undefined }, tabIndex: -1, role: "listbox", "aria-activedescendant": isUndefined(focusItem) ? undefined : getItemId(focusItem.value) }, { children: dList.length === 0 ? (_jsx("li", Object.assign({ className: `${dPrefix}auto-complete__empty` }, { children: _jsx("div", Object.assign({ className: `${dPrefix}auto-complete__option-content` }, { children: t('No Data') })) }))) : (vsList) }))) }))] })));
                    } })), containerRef.current)] }));
}
export const DAutoComplete = React.forwardRef(AutoComplete);
